@@ -12,8 +12,8 @@
 from anyvc import apipkg
 apipkg.initpkg(__name__,{
     'workdir':{
-        'all_known':'anyvc._workdir:all_known',
-        'get_workdir_manager_for_path':'anyvc._workdir:get_workdir_manager_for_path',
+        'clone':'anyvc._workdir:clone',
+        'checkout': 'anyvc._workdir:checkout',
         'open':'anyvc._workdir:open',
         },
     })
